# python-project-skeleton

[![Codacy Badge](https://api.codacy.com/project/badge/grade/912d75f595c64fbe9e0eebcfeda69992)](https://www.codacy.com/app/pasuder/python-project-skeleton)

[![Code Climate](https://codeclimate.com/github/pasuder/python-project-skeleton/badges/gpa.svg)](https://codeclimate.com/github/pasuder/python-project-skeleton)
[![Test Coverage](https://codeclimate.com/github/pasuder/python-project-skeleton/badges/coverage.svg)](https://codeclimate.com/github/pasuder/python-project-skeleton/coverage)
[![Issue Count](https://codeclimate.com/github/pasuder/python-project-skeleton/badges/issue_count.svg)](https://codeclimate.com/github/pasuder/python-project-skeleton)

## Requirements

* `python` with `pip` and `virtualenv`

## How to deploy

* Clone this project.
* Create python virtual environment using `bin/install.sh`
* Import project to your favorite IDE.

## How to use (PyPi)

Simply. Add to `requirements.txt`

    -e git+git://github.com/your-name/python-project-skeleton#egg=python-project-skeleton

You can install it by python-installer

    pip install -e git+git://github.com/your-name/python-project-skeleton#egg=python-project-skeleton

## How to contribute

Clone this repo, setup your environment using `bin/install.sh`. Change what you want to change and make pull request.
